@@ -20,4 +20,4 @@
 
 # usage:  ./github-changes 0.20.0 0.20.1
 # will overwrites the local CHANGELOG.md, somehow you need to merge it in
-github-changes -o apache -r incubator-superset --token $GITHUB_TOKEN --between-tags $1...$2
+github-changes -o apache -r superset --token $GITHUB_TOKEN --between-tags $1...$2
