@@ -30,11 +30,10 @@ import {
   Table,
 } from 'react-virtualized';
 import { getMultipleTextDimensions, t, styled } from '@superset-ui/core';
-
+import { Tooltip } from 'src/components/Tooltip';
 import Button from '../Button';
 import CopyToClipboard from '../CopyToClipboard';
 import ModalTrigger from '../ModalTrigger';
-import TooltipWrapper from '../TooltipWrapper';
 
 function safeJsonObjectParse(
   data: unknown,
@@ -84,8 +83,10 @@ const JSON_TREE_THEME = {
 };
 
 const StyledFilterableTable = styled.div`
+  height: 100%;
   overflow-x: auto;
-  margin-top: ${({ theme }) => theme.gridUnit * 12}px;
+  margin-top: ${({ theme }) => theme.gridUnit * 2}px;
+  overflow-y: hidden;
 `;
 
 // when more than MAX_COLUMNS_FOR_TABLE are returned, switch from table to grid view
@@ -314,7 +315,7 @@ export default class FilterableTable extends PureComponent<
             <CopyToClipboard shouldShowText={false} text={jsonString} />
           </Button>
         }
-        modalTitle={t('Cell Content')}
+        modalTitle={t('Cell content')}
         triggerNode={node}
       />
     );
@@ -358,14 +359,14 @@ export default class FilterableTable extends PureComponent<
         ? 'header-style-disabled'
         : 'header-style';
     return (
-      <TooltipWrapper label="header" tooltip={label}>
+      <Tooltip id="header-tooltip" title={label}>
         <div className={className}>
           {label}
           {sortBy === dataKey && (
             <SortIndicator sortDirection={sortDirection} />
           )}
         </div>
-      </TooltipWrapper>
+      </Tooltip>
     );
   }
 
@@ -384,7 +385,7 @@ export default class FilterableTable extends PureComponent<
         ? 'header-style-disabled'
         : 'header-style';
     return (
-      <TooltipWrapper key={key} label="header" tooltip={label}>
+      <Tooltip key={key} id="header-tooltip" title={label}>
         <div
           style={{
             ...style,
@@ -395,9 +396,9 @@ export default class FilterableTable extends PureComponent<
           }}
           className={`${className} grid-cell grid-header-cell`}
         >
-          {label}
+          <div>{label}</div>
         </div>
-      </TooltipWrapper>
+      </Tooltip>
     );
   }
 
@@ -427,7 +428,7 @@ export default class FilterableTable extends PureComponent<
         }}
         className={`grid-cell ${this.rowClassName({ index: rowIndex })}`}
       >
-        {content}
+        <div>{content}</div>
       </div>
     );
 
@@ -467,7 +468,6 @@ export default class FilterableTable extends PureComponent<
         <ScrollSync>
           {({ onScroll, scrollTop }) => (
             <div
-              style={{ height }}
               className="filterable-table-container Table"
               data-test="filterable-table-container"
               ref={this.container}
@@ -560,7 +560,6 @@ export default class FilterableTable extends PureComponent<
       this.getDatum(sortedAndFilteredList, index);
     return (
       <StyledFilterableTable
-        style={{ height }}
         className="filterable-table-container"
         ref={this.container}
       >
