@@ -17,19 +17,29 @@
  * under the License.
  */
 /* eslint camelcase: 0 */
-import React, { useEffect, useState } from 'react';
+import React, { useCallback, useEffect, useMemo, useState } from 'react';
 import PropTypes from 'prop-types';
 import { bindActionCreators } from 'redux';
 import { connect } from 'react-redux';
-import { styled, t, supersetTheme, css } from '@superset-ui/core';
+import { styled, t, css, useTheme } from '@superset-ui/core';
 import { debounce } from 'lodash';
 import { Resizable } from 're-resizable';
 
-import { useDynamicPluginContext } from 'src/components/DynamicPlugins';
-import { Global } from '@emotion/core';
-import { Tooltip } from 'src/common/components/Tooltip';
+import { usePluginContext } from 'src/components/DynamicPlugins';
+import { Global } from '@emotion/react';
+import { Tooltip } from 'src/components/Tooltip';
 import { usePrevious } from 'src/common/hooks/usePrevious';
-import Icon from 'src/components/Icon';
+import Icons from 'src/components/Icons';
+import {
+  getFromLocalStorage,
+  setInLocalStorage,
+} from 'src/utils/localStorageHelpers';
+import { URL_PARAMS } from 'src/constants';
+import cx from 'classnames';
+import * as chartActions from 'src/chart/chartAction';
+import { fetchDatasourceMetadata } from 'src/dashboard/actions/datasources';
+import { chartPropShape } from 'src/dashboard/util/propShapes';
+import { mergeExtraFormData } from 'src/dashboard/components/nativeFilters/utils';
 import ExploreChartPanel from './ExploreChartPanel';
 import ConnectedControlPanelsContainer from './ControlPanelsContainer';
 import SaveModal from './SaveModal';
@@ -38,11 +48,8 @@ import DataSourcePanel from './DatasourcePanel';
 import { getExploreLongUrl } from '../exploreUtils';
 import { areObjectsEqual } from '../../reduxUtils';
 import { getFormDataFromControls } from '../controlUtils';
-import { chartPropShape } from '../../dashboard/util/propShapes';
 import * as exploreActions from '../actions/exploreActions';
 import * as saveModalActions from '../actions/saveModalActions';
-import * as chartActions from '../../chart/chartAction';
-import { fetchDatasourceMetadata } from '../../dashboard/actions/datasources';
 import * as logActions from '../../logger/actions';
 import {
   LOG_ACTIONS_MOUNT_EXPLORER,
@@ -63,7 +70,7 @@ const propTypes = {
   controls: PropTypes.object.isRequired,
   forcedHeight: PropTypes.string,
   form_data: PropTypes.object.isRequired,
-  standalone: PropTypes.bool.isRequired,
+  standalone: PropTypes.number.isRequired,
   timeout: PropTypes.number,
   impressionId: PropTypes.string,
   vizType: PropTypes.string,
@@ -74,10 +81,11 @@ const Styles = styled.div`
   text-align: left;
   position: relative;
   width: 100%;
-  height: 100%;
+  max-height: 100%;
   display: flex;
   flex-direction: row;
   flex-wrap: nowrap;
+  flex-basis: 100vh;
   align-items: stretch;
   border-top: 1px solid ${({ theme }) => theme.colors.grayscale.light2};
   .explore-column {
@@ -95,6 +103,9 @@ const Styles = styled.div`
     flex: 1;
     min-width: ${({ theme }) => theme.gridUnit * 128}px;
     border-left: 1px solid ${({ theme }) => theme.colors.grayscale.light2};
+    .panel {
+      margin-bottom: 0;
+    }
   }
   .controls-column {
     align-self: flex-start;
@@ -148,47 +159,65 @@ function useWindowSize({ delayMs = 250 } = {}) {
 }
 
 function ExploreViewContainer(props) {
-  const dynamicPluginContext = useDynamicPluginContext();
-  const dynamicPlugin = dynamicPluginContext.plugins[props.vizType];
-  const isDynamicPluginLoading = dynamicPlugin && dynamicPlugin.loading;
+  const dynamicPluginContext = usePluginContext();
+  const dynamicPlugin = dynamicPluginContext.dynamicPlugins[props.vizType];
+  const isDynamicPluginLoading = dynamicPlugin && dynamicPlugin.mounting;
   const wasDynamicPluginLoading = usePrevious(isDynamicPluginLoading);
 
+  /** the state of controls in the previous render */
   const previousControls = usePrevious(props.controls);
+  /** the state of controls last time a query was triggered */
+  const [lastQueriedControls, setLastQueriedControls] = useState(
+    props.controls,
+  );
   const windowSize = useWindowSize();
 
   const [showingModal, setShowingModal] = useState(false);
-  const [chartIsStale, setChartIsStale] = useState(false);
   const [isCollapsed, setIsCollapsed] = useState(false);
 
+  const theme = useTheme();
   const width = `${windowSize.width}px`;
   const navHeight = props.standalone ? 0 : 90;
   const height = props.forcedHeight
     ? `${props.forcedHeight}px`
     : `${windowSize.height - navHeight}px`;
 
-  function addHistory({ isReplace = false, title } = {}) {
-    const payload = { ...props.form_data };
-    const longUrl = getExploreLongUrl(
-      props.form_data,
-      props.standalone ? 'standalone' : null,
-      false,
-    );
-    try {
-      if (isReplace) {
-        window.history.replaceState(payload, title, longUrl);
-      } else {
-        window.history.pushState(payload, title, longUrl);
-      }
-    } catch (e) {
-      // eslint-disable-next-line no-console
-      console.warn(
-        'Failed at altering browser history',
-        payload,
-        title,
-        longUrl,
+  const storageKeys = {
+    controlsWidth: 'controls_width',
+    dataSourceWidth: 'datasource_width',
+  };
+
+  const defaultSidebarsWidth = {
+    controls_width: 320,
+    datasource_width: 300,
+  };
+
+  const addHistory = useCallback(
+    ({ isReplace = false, title } = {}) => {
+      const payload = { ...props.form_data };
+      const longUrl = getExploreLongUrl(
+        props.form_data,
+        props.standalone ? URL_PARAMS.standalone.name : null,
+        false,
       );
-    }
-  }
+      try {
+        if (isReplace) {
+          window.history.replaceState(payload, title, longUrl);
+        } else {
+          window.history.pushState(payload, title, longUrl);
+        }
+      } catch (e) {
+        // eslint-disable-next-line no-console
+        console.warn(
+          'Failed at altering browser history',
+          payload,
+          title,
+          longUrl,
+        );
+      }
+    },
+    [props.form_data, props.standalone],
+  );
 
   function handlePopstate() {
     const formData = window.history.state;
@@ -202,15 +231,11 @@ function ExploreViewContainer(props) {
       );
     }
   }
-
-  function onQuery() {
-    // remove alerts when query
-    props.actions.removeControlPanelAlert();
+  const onQuery = useCallback(() => {
     props.actions.triggerQuery(true, props.chart.id);
-
-    setChartIsStale(false);
     addHistory();
-  }
+    setLastQueriedControls(props.controls);
+  }, [props.controls, addHistory, props.actions, props.chart.id]);
 
   function handleKeydown(event) {
     const controlOrCommand = event.ctrlKey || event.metaKey;
@@ -280,12 +305,18 @@ function ExploreViewContainer(props) {
     }
   }, []);
 
+  const reRenderChart = () => {
+    props.actions.updateQueryFormData(
+      getFormDataFromControls(props.controls),
+      props.chart.id,
+    );
+    props.actions.renderTriggered(new Date().getTime(), props.chart.id);
+    addHistory();
+  };
+
   // effect to run when controls change
   useEffect(() => {
     if (previousControls) {
-      if (props.controls.viz_type.value !== previousControls.viz_type.value) {
-        props.actions.resetControls();
-      }
       if (
         props.controls.datasource &&
         (previousControls.datasource == null ||
@@ -309,41 +340,72 @@ function ExploreViewContainer(props) {
         key => props.controls[key].renderTrigger,
       );
       if (hasDisplayControlChanged) {
-        props.actions.updateQueryFormData(
-          getFormDataFromControls(props.controls),
-          props.chart.id,
-        );
-        props.actions.renderTriggered(new Date().getTime(), props.chart.id);
-        addHistory();
+        reRenderChart();
       }
+    }
+  }, [props.controls, props.ownState]);
 
-      // this should be handled inside actions too
-      const hasQueryControlChanged = changedControlKeys.some(
+  const chartIsStale = useMemo(() => {
+    if (lastQueriedControls) {
+      const changedControlKeys = Object.keys(props.controls).filter(
+        key =>
+          typeof lastQueriedControls[key] !== 'undefined' &&
+          !areObjectsEqual(
+            props.controls[key].value,
+            lastQueriedControls[key].value,
+          ),
+      );
+
+      return changedControlKeys.some(
         key =>
           !props.controls[key].renderTrigger &&
           !props.controls[key].dontRefreshOnChange,
       );
-      if (hasQueryControlChanged) {
-        props.actions.logEvent(LOG_ACTIONS_CHANGE_EXPLORE_CONTROLS);
-        setChartIsStale(true);
-      }
     }
-  }, [props.controls]);
+    return false;
+  }, [lastQueriedControls, props.controls]);
+
+  useEffect(() => {
+    if (props.ownState !== undefined) {
+      onQuery();
+      reRenderChart();
+    }
+  }, [props.ownState]);
+
+  if (chartIsStale) {
+    props.actions.logEvent(LOG_ACTIONS_CHANGE_EXPLORE_CONTROLS);
+  }
 
   function renderErrorMessage() {
     // Returns an error message as a node if any errors are in the store
-    const errors = Object.entries(props.controls)
-      .filter(
-        ([, control]) =>
-          control.validationErrors && control.validationErrors.length > 0,
-      )
-      .map(([key, control]) => (
-        <div key={key}>
-          {t('Control labeled ')}
-          <strong>{` "${control.label}" `}</strong>
-          {control.validationErrors.join('. ')}
+    const controlsWithErrors = Object.values(props.controls).filter(
+      control =>
+        control.validationErrors && control.validationErrors.length > 0,
+    );
+    if (controlsWithErrors.length === 0) {
+      return null;
+    }
+
+    const errorMessages = controlsWithErrors.map(
+      control => control.validationErrors,
+    );
+    const uniqueErrorMessages = [...new Set(errorMessages.flat())];
+
+    const errors = uniqueErrorMessages
+      .map(message => {
+        const matchingLabels = controlsWithErrors
+          .filter(control => control.validationErrors?.includes(message))
+          .map(control => control.label);
+        return [matchingLabels, message];
+      })
+      .map(([labels, message]) => (
+        <div key={message}>
+          {labels.length > 1 ? t('Controls labeled ') : t('Control labeled ')}
+          <strong>{` ${labels.join(', ')}`}</strong>
+          <span>: {message}</span>
         </div>
       ));
+
     let errorMessage;
     if (errors.length > 0) {
       errorMessage = <div style={{ textAlign: 'left' }}>{errors}</div>;
@@ -365,6 +427,15 @@ function ExploreViewContainer(props) {
     );
   }
 
+  function getSidebarWidths(key) {
+    return getFromLocalStorage(key, defaultSidebarsWidth[key]);
+  }
+
+  function setSidebarWidths(key, dimension) {
+    const newDimension = Number(getSidebarWidths(key)) + dimension.width;
+    setInLocalStorage(key, newDimension);
+  }
+
   if (props.standalone) {
     return renderChartContainer();
   }
@@ -377,6 +448,7 @@ function ExploreViewContainer(props) {
             margin-bottom: 0;
           }
           body {
+            height: 100vh;
             max-height: 100vh;
             overflow: hidden;
           }
@@ -387,7 +459,7 @@ function ExploreViewContainer(props) {
           #app {
             flex-basis: 100%;
             overflow: hidden;
-            height: 100vh;
+            height: 100%;
           }
           #app-menu {
             flex-shrink: 0;
@@ -404,8 +476,14 @@ function ExploreViewContainer(props) {
         />
       )}
       <Resizable
-        defaultSize={{ width: 300 }}
-        minWidth={300}
+        onResizeStop={(evt, direction, ref, d) =>
+          setSidebarWidths(storageKeys.dataSourceWidth, d)
+        }
+        defaultSize={{
+          width: getSidebarWidths(storageKeys.dataSourceWidth),
+          height: '100%',
+        }}
+        minWidth={defaultSidebarsWidth[storageKeys.dataSourceWidth]}
         maxWidth="33%"
         enable={{ right: true }}
         className={
@@ -420,11 +498,10 @@ function ExploreViewContainer(props) {
             className="action-button"
             onClick={toggleCollapse}
           >
-            <Icon
-              name="expand"
-              color={supersetTheme.colors.primary.base}
+            <Icons.Expand
               className="collapse-icon"
-              width={16}
+              iconColor={theme.colors.primary.base}
+              iconSize="l"
             />
           </span>
         </div>
@@ -443,21 +520,30 @@ function ExploreViewContainer(props) {
           tabIndex={0}
         >
           <span role="button" tabIndex={0} className="action-button">
-            <Tooltip title={t('Open Datasource Tab')}>
-              <Icon
-                name="collapse"
-                color={supersetTheme.colors.primary.base}
+            <Tooltip title={t('Open Datasource tab')}>
+              <Icons.Collapse
                 className="collapse-icon"
-                width={16}
+                iconColor={theme.colors.primary.base}
+                iconSize="l"
               />
             </Tooltip>
           </span>
-          <Icon name="dataset-physical" width={16} />
+          <Icons.DatasetPhysical
+            css={{ marginTop: theme.gridUnit * 2 }}
+            iconSize="l"
+            iconColor={theme.colors.grayscale.base}
+          />
         </div>
       ) : null}
       <Resizable
-        defaultSize={{ width: 320 }}
-        minWidth={320}
+        onResizeStop={(evt, direction, ref, d) =>
+          setSidebarWidths(storageKeys.controlsWidth, d)
+        }
+        defaultSize={{
+          width: getSidebarWidths(storageKeys.controlsWidth),
+          height: '100%',
+        }}
+        minWidth={defaultSidebarsWidth[storageKeys.controlsWidth]}
         maxWidth="33%"
         enable={{ right: true }}
         className="col-sm-3 explore-column controls-column"
@@ -481,9 +567,10 @@ function ExploreViewContainer(props) {
         />
       </Resizable>
       <div
-        className={`main-explore-content ${
-          isCollapsed ? 'col-sm-9' : 'col-sm-7'
-        }`}
+        className={cx(
+          'main-explore-content',
+          isCollapsed ? 'col-sm-9' : 'col-sm-7',
+        )}
       >
         {renderChartContainer()}
       </div>
@@ -494,8 +581,14 @@ function ExploreViewContainer(props) {
 ExploreViewContainer.propTypes = propTypes;
 
 function mapStateToProps(state) {
-  const { explore, charts, impressionId } = state;
+  const { explore, charts, impressionId, dataMask, reports } = state;
   const form_data = getFormDataFromControls(explore.controls);
+  form_data.extra_form_data = mergeExtraFormData(
+    { ...form_data.extra_form_data },
+    {
+      ...dataMask[form_data.slice_id ?? 0]?.ownState, // 0 - unsaved chart
+    },
+  );
   const chartKey = Object.keys(charts)[0];
   const chart = charts[chartKey];
   return {
@@ -525,7 +618,11 @@ function mapStateToProps(state) {
     forcedHeight: explore.forced_height,
     chart,
     timeout: explore.common.conf.SUPERSET_WEBSERVER_TIMEOUT,
+    ownState: dataMask[form_data.slice_id ?? 0]?.ownState, // 0 - unsaved chart
     impressionId,
+    userId: explore.user_id,
+    user: explore.user,
+    reports,
   };
 }
 
