@@ -18,13 +18,15 @@
  */
 /* eslint camelcase: 0 */
 import React from 'react';
-import { Alert, FormControl, FormGroup, Radio } from 'react-bootstrap';
+import { Input } from 'src/common/components';
+import { Form, FormItem } from 'src/components/Form';
+import Alert from 'src/components/Alert';
 import { JsonObject, t, styled } from '@superset-ui/core';
 import ReactMarkdown from 'react-markdown';
-import Modal from 'src/common/components/Modal';
+import Modal from 'src/components/Modal';
+import { Radio } from 'src/components/Radio';
 import Button from 'src/components/Button';
-import FormLabel from 'src/components/FormLabel';
-import { CreatableSelect } from 'src/components/Select/SupersetStyledSelect';
+import { CreatableSelect } from 'src/components/Select';
 import { connect } from 'react-redux';
 
 // Session storage key for recent dashboard
@@ -99,9 +101,7 @@ class SaveModal extends React.Component<SaveModalProps, SaveModalState> {
     });
   }
 
-  onSliceNameChange(
-    event: React.FormEvent<FormControl> & { target: HTMLInputElement },
-  ) {
+  onSliceNameChange(event: React.ChangeEvent<HTMLInputElement>) {
     this.setState({ newSliceName: event.target.value });
   }
 
@@ -158,19 +158,28 @@ class SaveModal extends React.Component<SaveModalProps, SaveModalState> {
   }
 
   render() {
+    const dashboardSelectValue =
+      this.state.saveToDashboardId || this.state.newDashboardName;
+    const valueObj = dashboardSelectValue
+      ? { value: dashboardSelectValue }
+      : null;
     return (
       <StyledModal
         show
         onHide={this.props.onHide}
-        title={t('Save Chart')}
+        title={t('Save chart')}
         footer={
           <div data-test="save-modal-footer">
-            <Button id="btn_cancel" buttonSize="sm" onClick={this.props.onHide}>
+            <Button
+              id="btn_cancel"
+              buttonSize="small"
+              onClick={this.props.onHide}
+            >
               {t('Cancel')}
             </Button>
             <Button
               id="btn_modal_save_goto_dash"
-              buttonSize="sm"
+              buttonSize="small"
               disabled={
                 !this.state.newSliceName ||
                 (!this.state.saveToDashboardId && !this.state.newDashboardName)
@@ -181,7 +190,7 @@ class SaveModal extends React.Component<SaveModalProps, SaveModalState> {
             </Button>
             <Button
               id="btn_modal_save"
-              buttonSize="sm"
+              buttonSize="small"
               buttonStyle="primary"
               onClick={() => this.saveOrOverwrite(false)}
               disabled={!this.state.newSliceName}
@@ -194,24 +203,28 @@ class SaveModal extends React.Component<SaveModalProps, SaveModalState> {
           </div>
         }
       >
-        <div data-test="save-modal-body">
+        <Form data-test="save-modal-body" layout="vertical">
           {(this.state.alert || this.props.alert) && (
-            <Alert>
-              {this.state.alert ? this.state.alert : this.props.alert}
-              <i
-                role="button"
-                aria-label="Remove alert"
-                tabIndex={0}
-                className="fa fa-close pull-right"
-                onClick={this.removeAlert.bind(this)}
-                style={{ cursor: 'pointer' }}
-              />
-            </Alert>
+            <Alert
+              type="warning"
+              message={
+                <>
+                  {this.state.alert ? this.state.alert : this.props.alert}
+                  <i
+                    role="button"
+                    aria-label="Remove alert"
+                    tabIndex={0}
+                    className="fa fa-close pull-right"
+                    onClick={this.removeAlert.bind(this)}
+                    style={{ cursor: 'pointer' }}
+                  />
+                </>
+              }
+            />
           )}
-          <FormGroup data-test="radio-group">
+          <FormItem data-test="radio-group">
             <Radio
               id="overwrite-radio"
-              inline
               disabled={!(this.props.can_overwrite && this.props.slice)}
               checked={this.state.action === 'overwrite'}
               onChange={() => this.changeAction('overwrite')}
@@ -222,41 +235,38 @@ class SaveModal extends React.Component<SaveModalProps, SaveModalState> {
             <Radio
               id="saveas-radio"
               data-test="saveas-radio"
-              inline
               checked={this.state.action === 'saveas'}
               onChange={() => this.changeAction('saveas')}
             >
               {' '}
               {t('Save as ...')} &nbsp;
             </Radio>
-          </FormGroup>
+          </FormItem>
           <hr />
-          <FormGroup>
-            <FormLabel required>{t('Chart name')}</FormLabel>
-            <FormControl
+          <FormItem label={t('Chart name')} required>
+            <Input
               name="new_slice_name"
               type="text"
-              bsSize="sm"
               placeholder="Name"
               value={this.state.newSliceName}
               onChange={this.onSliceNameChange}
               data-test="new-chart-name"
             />
-          </FormGroup>
-          <FormGroup data-test="save-chart-modal-select-dashboard-form">
-            <FormLabel>{t('Add to dashboard')}</FormLabel>
+          </FormItem>
+          <FormItem
+            label={t('Add to dashboard')}
+            data-test="save-chart-modal-select-dashboard-form"
+          >
             <CreatableSelect
               id="dashboard-creatable-select"
               className="save-modal-selector"
+              menuPosition="fixed"
               options={this.props.dashboards}
               clearable
               creatable
               onChange={this.onDashboardSelectChange}
               autoSize={false}
-              value={{
-                value:
-                  this.state.saveToDashboardId || this.state.newDashboardName,
-              }}
+              value={valueObj}
               placeholder={
                 // Using markdown to allow for good i18n
                 <ReactMarkdown
@@ -265,8 +275,8 @@ class SaveModal extends React.Component<SaveModalProps, SaveModalState> {
                 />
               }
             />
-          </FormGroup>
-        </div>
+          </FormItem>
+        </Form>
       </StyledModal>
     );
   }
