@@ -17,22 +17,21 @@
  * under the License.
  */
 
-import React, { useState, useMemo } from 'react';
+import React, { useState, useMemo, useEffect } from 'react';
 import { useHistory } from 'react-router-dom';
 import { t, SupersetClient, makeApi, styled } from '@superset-ui/core';
 import moment from 'moment';
 import ActionsBar, { ActionProps } from 'src/components/ListView/ActionsBar';
 import Button from 'src/components/Button';
 import FacePile from 'src/components/FacePile';
-import { IconName } from 'src/components/Icon';
-import { Tooltip } from 'src/common/components/Tooltip';
+import { Tooltip } from 'src/components/Tooltip';
 import ListView, {
-  FilterOperators,
+  FilterOperator,
   Filters,
   ListViewProps,
 } from 'src/components/ListView';
 import SubMenu, { SubMenuProps } from 'src/components/Menu/SubMenu';
-import { Switch } from 'src/common/components/Switch';
+import { Switch } from 'src/components/Switch';
 import { DATETIME_WITH_TIME_ZONE } from 'src/constants';
 import withToasts from 'src/messageToasts/enhancers/withToasts';
 import AlertStatusIcon from 'src/views/CRUD/alert/components/AlertStatusIcon';
@@ -85,7 +84,7 @@ function AlertList({
     () => [
       {
         id: 'type',
-        operator: FilterOperators.equals,
+        operator: FilterOperator.equals,
         value: isReportEnabled ? 'Report' : 'Alert',
       },
     ],
@@ -137,6 +136,12 @@ function AlertList({
   const canDelete = hasPerm('can_write');
   const canCreate = hasPerm('can_write');
 
+  useEffect(() => {
+    if (bulkSelectEnabled && canDelete) {
+      toggleBulkSelect();
+    }
+  }, [isReportEnabled]);
+
   const handleAlertDelete = ({ id, name }: AlertObject) => {
     SupersetClient.delete({
       endpoint: `/api/v1/report/${id}`,
@@ -210,7 +215,7 @@ function AlertList({
             ? moment.utc(lastEvalDttm).local().format(DATETIME_WITH_TIME_ZONE)
             : '',
         accessor: 'last_eval_dttm',
-        Header: t('Last Run'),
+        Header: t('Last run'),
         size: 'lg',
       },
       {
@@ -242,7 +247,7 @@ function AlertList({
             <RecipientIcon key={r.id} type={r.type} />
           )),
         accessor: 'recipients',
-        Header: t('Notification Method'),
+        Header: t('Notification method'),
         disableSortBy: true,
         size: 'xl',
       },
@@ -289,9 +294,9 @@ function AlertList({
             canEdit
               ? {
                   label: 'execution-log-action',
-                  tooltip: t('Execution Log'),
+                  tooltip: t('Execution log'),
                   placement: 'bottom',
-                  icon: 'note' as IconName,
+                  icon: 'Note',
                   onClick: handleGotoExecutionLog,
                 }
               : null,
@@ -300,7 +305,7 @@ function AlertList({
                   label: 'edit-action',
                   tooltip: t('Edit'),
                   placement: 'bottom',
-                  icon: 'edit' as IconName,
+                  icon: 'Edit',
                   onClick: handleEdit,
                 }
               : null,
@@ -309,7 +314,7 @@ function AlertList({
                   label: 'delete-action',
                   tooltip: t('Delete'),
                   placement: 'bottom',
-                  icon: 'trash' as IconName,
+                  icon: 'Trash',
                   onClick: handleDelete,
                 }
               : null,
@@ -344,7 +349,7 @@ function AlertList({
   }
   if (canDelete) {
     subMenuButtons.push({
-      name: t('Bulk Select'),
+      name: t('Bulk select'),
       onClick: toggleBulkSelect,
       buttonStyle: 'secondary',
       'data-test': 'bulk-select-toggle',
@@ -365,10 +370,10 @@ function AlertList({
   const filters: Filters = useMemo(
     () => [
       {
-        Header: t('Created By'),
+        Header: t('Created by'),
         id: 'created_by',
         input: 'select',
-        operator: FilterOperators.relationOneMany,
+        operator: FilterOperator.relationOneMany,
         unfilteredLabel: 'All',
         fetchSelects: createFetchRelated(
           'report',
@@ -384,7 +389,7 @@ function AlertList({
         Header: t('Status'),
         id: 'last_state',
         input: 'select',
-        operator: FilterOperators.equals,
+        operator: FilterOperator.equals,
         unfilteredLabel: 'Any',
         selects: [
           { label: t(`${AlertState.success}`), value: AlertState.success },
@@ -398,7 +403,7 @@ function AlertList({
         Header: t('Search'),
         id: 'name',
         input: 'search',
-        operator: FilterOperators.contains,
+        operator: FilterOperator.contains,
       },
     ],
     [],
@@ -408,19 +413,21 @@ function AlertList({
     <>
       <SubMenu
         activeChild={pathName}
-        name={t('Alerts & Reports')}
+        name={t('Alerts & reports')}
         tabs={[
           {
             name: 'Alerts',
             label: t('Alerts'),
             url: '/alert/list/',
             usesRouter: true,
+            'data-test': 'alert-list',
           },
           {
             name: 'Reports',
             label: t('Reports'),
             url: '/report/list/',
             usesRouter: true,
+            'data-test': 'report-list',
           },
         ]}
         buttons={subMenuButtons}
@@ -435,6 +442,7 @@ function AlertList({
         layer={currentAlert}
         onHide={() => {
           setAlertModalOpen(false);
+          setCurrentAlert(null);
           refreshData();
         }}
         show={alertModalOpen}
