@@ -18,7 +18,7 @@
  */
 import React, { FunctionComponent } from 'react';
 import { styled, t } from '@superset-ui/core';
-import Modal from 'src/common/components/Modal';
+import Modal from 'src/components/Modal';
 import Button from 'src/components/Button';
 import SyntaxHighlighterCopy from 'src/views/CRUD/data/components/SyntaxHighlighterCopy';
 import withToasts, { ToastProps } from 'src/messageToasts/enhancers/withToasts';
@@ -95,7 +95,7 @@ const SavedQueryPreviewModal: FunctionComponent<SavedQueryPreviewModalProps> = (
       <StyledModal
         onHide={onHide}
         show={show}
-        title={t('Query Preview')}
+        title={t('Query preview')}
         footer={[
           <Button
             data-test="previous-saved-query"
@@ -123,7 +123,7 @@ const SavedQueryPreviewModal: FunctionComponent<SavedQueryPreviewModalProps> = (
           </Button>,
         ]}
       >
-        <QueryTitle>{t('Query Name')}</QueryTitle>
+        <QueryTitle>{t('Query name')}</QueryTitle>
         <QueryLabel>{savedQuery.label}</QueryLabel>
         <SyntaxHighlighterCopy
           language="sql"
