@@ -19,9 +19,10 @@ import json
 import logging
 import sys
 from datetime import datetime, timedelta
+from pathlib import Path
 from subprocess import Popen
 from typing import Any, Dict, List, Optional, Type, Union
-from zipfile import ZipFile
+from zipfile import is_zipfile, ZipFile
 
 import click
 import yaml
@@ -30,7 +31,6 @@ from colorama import Fore, Style
 from flask import current_app, g
 from flask.cli import FlaskGroup, with_appcontext
 from flask_appbuilder import Model
-from pathlib2 import Path
 
 from superset import app, appbuilder, config, security_manager
 from superset.app import create_app
@@ -109,7 +109,10 @@ def version(verbose: bool) -> None:
 
 
 def load_examples_run(
-    load_test_data: bool, only_metadata: bool = False, force: bool = False
+    load_test_data: bool = False,
+    load_big_data: bool = False,
+    only_metadata: bool = False,
+    force: bool = False,
 ) -> None:
     if only_metadata:
         print("Loading examples metadata")
@@ -121,8 +124,9 @@ def load_examples_run(
 
     examples.load_css_templates()
 
-    print("Loading energy related dataset")
-    examples.load_energy(only_metadata, force)
+    if load_test_data:
+        print("Loading energy related dataset")
+        examples.load_energy(only_metadata, force)
 
     print("Loading [World Bank's Health Nutrition and Population Stats]")
     examples.load_world_bank_health_n_pop(only_metadata, force)
@@ -130,22 +134,17 @@ def load_examples_run(
     print("Loading [Birth names]")
     examples.load_birth_names(only_metadata, force)
 
-    if not load_test_data:
-        print("Loading [Random time series data]")
-        examples.load_random_time_series_data(only_metadata, force)
+    if load_test_data:
+        print("Loading [Tabbed dashboard]")
+        examples.load_tabbed_dashboard(only_metadata)
 
+    if not load_test_data:
         print("Loading [Random long/lat data]")
         examples.load_long_lat_data(only_metadata, force)
 
         print("Loading [Country Map data]")
         examples.load_country_map_data(only_metadata, force)
 
-        print("Loading [Multiformat time series]")
-        examples.load_multiformat_time_series(only_metadata, force)
-
-        print("Loading [Paris GeoJson]")
-        examples.load_paris_iris_geojson(only_metadata, force)
-
         print("Loading [San Francisco population polygons]")
         examples.load_sf_population_polygons(only_metadata, force)
 
@@ -164,16 +163,18 @@ def load_examples_run(
         print("Loading DECK.gl demo")
         examples.load_deck_dash()
 
-    print("Loading [Tabbed dashboard]")
-    examples.load_tabbed_dashboard(only_metadata)
+    if load_big_data:
+        print("Loading big synthetic data for tests")
+        examples.load_big_data()
 
     # load examples that are stored as YAML config files
-    examples.load_from_configs(force)
+    examples.load_from_configs(force, load_test_data)
 
 
 @with_appcontext
 @superset.command()
 @click.option("--load-test-data", "-t", is_flag=True, help="Load additional test data")
+@click.option("--load-big-data", "-b", is_flag=True, help="Load additional big data")
 @click.option(
     "--only-metadata", "-m", is_flag=True, help="Only load metadata, skip actual data"
 )
@@ -181,19 +182,29 @@ def load_examples_run(
     "--force", "-f", is_flag=True, help="Force load data even if table already exists"
 )
 def load_examples(
-    load_test_data: bool, only_metadata: bool = False, force: bool = False
+    load_test_data: bool,
+    load_big_data: bool,
+    only_metadata: bool = False,
+    force: bool = False,
 ) -> None:
     """Loads a set of Slices and Dashboards and a supporting dataset """
-    load_examples_run(load_test_data, only_metadata, force)
+    load_examples_run(load_test_data, load_big_data, only_metadata, force)
 
 
 @with_appcontext
 @superset.command()
 @click.option("--database_name", "-d", help="Database name to change")
 @click.option("--uri", "-u", help="Database URI to change")
-def set_database_uri(database_name: str, uri: str) -> None:
+@click.option(
+    "--skip_create",
+    "-s",
+    is_flag=True,
+    default=False,
+    help="Create the DB if it doesn't exist",
+)
+def set_database_uri(database_name: str, uri: str, skip_create: bool) -> None:
     """Updates a database connection URI """
-    utils.get_or_create_db(database_name, uri)
+    utils.get_or_create_db(database_name, uri, not skip_create)
 
 
 @superset.command()
@@ -232,12 +243,9 @@ if feature_flags.get("VERSIONED_EXPORT"):
     @superset.command()
     @with_appcontext
     @click.option(
-        "--dashboard-file",
-        "-f",
-        default="dashboard_export_YYYYMMDDTHHMMSS",
-        help="Specify the the file to export to",
+        "--dashboard-file", "-f", help="Specify the the file to export to",
     )
-    def export_dashboards(dashboard_file: Optional[str]) -> None:
+    def export_dashboards(dashboard_file: Optional[str] = None) -> None:
         """Export dashboards to ZIP file"""
         from superset.dashboards.commands.export import ExportDashboardsCommand
         from superset.models.dashboard import Dashboard
@@ -266,12 +274,9 @@ if feature_flags.get("VERSIONED_EXPORT"):
     @superset.command()
     @with_appcontext
     @click.option(
-        "--datasource-file",
-        "-f",
-        default="dataset_export_YYYYMMDDTHHMMSS",
-        help="Specify the the file to export to",
+        "--datasource-file", "-f", help="Specify the the file to export to",
     )
-    def export_datasources(datasource_file: Optional[str]) -> None:
+    def export_datasources(datasource_file: Optional[str] = None) -> None:
         """Export datasources to ZIP file"""
         from superset.connectors.sqla.models import SqlaTable
         from superset.datasets.commands.export import ExportDatasetsCommand
@@ -307,15 +312,20 @@ if feature_flags.get("VERSIONED_EXPORT"):
     )
     def import_dashboards(path: str, username: Optional[str]) -> None:
         """Import dashboards from ZIP file"""
+        from superset.commands.importers.v1.utils import get_contents_from_bundle
         from superset.dashboards.commands.importers.dispatcher import (
             ImportDashboardsCommand,
         )
 
         if username is not None:
             g.user = security_manager.find_user(username=username)
-        contents = {path: open(path).read()}
+        if is_zipfile(path):
+            with ZipFile(path) as bundle:
+                contents = get_contents_from_bundle(bundle)
+        else:
+            contents = {path: open(path).read()}
         try:
-            ImportDashboardsCommand(contents).run()
+            ImportDashboardsCommand(contents, overwrite=True).run()
         except Exception:  # pylint: disable=broad-except
             logger.exception(
                 "There was an error when importing the dashboards(s), please check "
@@ -325,36 +335,22 @@ if feature_flags.get("VERSIONED_EXPORT"):
     @superset.command()
     @with_appcontext
     @click.option(
-        "--path",
-        "-p",
-        help="Path to a single YAML file or path containing multiple YAML "
-        "files to import (*.yaml or *.yml)",
-    )
-    @click.option(
-        "--sync",
-        "-s",
-        "sync",
-        default="",
-        help="comma seperated list of element types to synchronize "
-        'e.g. "metrics,columns" deletes metrics and columns in the DB '
-        "that are not specified in the YAML file",
-    )
-    @click.option(
-        "--recursive",
-        "-r",
-        is_flag=True,
-        default=False,
-        help="recursively search the path for yaml files",
+        "--path", "-p", help="Path to a single ZIP file",
     )
     def import_datasources(path: str) -> None:
         """Import datasources from ZIP file"""
+        from superset.commands.importers.v1.utils import get_contents_from_bundle
         from superset.datasets.commands.importers.dispatcher import (
             ImportDatasetsCommand,
         )
 
-        contents = {path: open(path).read()}
+        if is_zipfile(path):
+            with ZipFile(path) as bundle:
+                contents = get_contents_from_bundle(bundle)
+        else:
+            contents = {path: open(path).read()}
         try:
-            ImportDatasetsCommand(contents).run()
+            ImportDatasetsCommand(contents, overwrite=True).run()
         except Exception:  # pylint: disable=broad-except
             logger.exception(
                 "There was an error when importing the dataset(s), please check the "
@@ -464,7 +460,7 @@ else:
         help="Specify the user name to assign dashboards to",
     )
     def import_dashboards(path: str, recursive: bool, username: str) -> None:
-        """Import dashboards from ZIP file"""
+        """Import dashboards from JSON file"""
         from superset.dashboards.commands.importers.v0 import ImportDashboardsCommand
 
         path_object = Path(path)
@@ -729,16 +725,23 @@ def load_test_users_run() -> None:
         gamma_sqllab_role = sm.add_role("gamma_sqllab")
         sm.add_permission_role(gamma_sqllab_role, examples_pv)
 
+        gamma_no_csv_role = sm.add_role("gamma_no_csv")
+        sm.add_permission_role(gamma_no_csv_role, examples_pv)
+
         for role in ["Gamma", "sql_lab"]:
             for perm in sm.find_role(role).permissions:
                 sm.add_permission_role(gamma_sqllab_role, perm)
 
+                if str(perm) != "can csv on Superset":
+                    sm.add_permission_role(gamma_no_csv_role, perm)
+
         users = (
             ("admin", "Admin"),
             ("gamma", "Gamma"),
             ("gamma2", "Gamma"),
             ("gamma_sqllab", "gamma_sqllab"),
             ("alpha", "Alpha"),
+            ("gamma_no_csv", "gamma_no_csv"),
         )
         for username, role in users:
             user = sm.find_user(username)
