@@ -15,21 +15,31 @@
 # specific language governing permissions and limitations
 # under the License.
 # pylint: disable=R
-import hashlib
 import logging
 from datetime import datetime, timedelta
-from typing import Any, Dict, List, NamedTuple, Optional, Union
+from typing import Any, Dict, List, NamedTuple, Optional
 
-import simplejson as json
 from flask_babel import gettext as _
 from pandas import DataFrame
 
-from superset import app, is_feature_enabled
+from superset import app, db
+from superset.connectors.base.models import BaseDatasource
+from superset.connectors.connector_registry import ConnectorRegistry
 from superset.exceptions import QueryObjectValidationError
-from superset.typing import Metric
+from superset.typing import Metric, OrderBy
 from superset.utils import pandas_postprocessing
-from superset.utils.core import DTTM_ALIAS, get_metric_names, json_int_dttm_ser
+from superset.utils.core import (
+    ChartDataResultType,
+    DatasourceDict,
+    DTTM_ALIAS,
+    find_duplicates,
+    get_metric_names,
+    is_adhoc_metric,
+    json_int_dttm_ser,
+    QueryObjectFilterClause,
+)
 from superset.utils.date_parser import get_since_until, parse_human_timedelta
+from superset.utils.hashing import md5_sha_from_dict
 from superset.views.utils import get_time_range_endpoints
 
 config = app.config
@@ -64,32 +74,42 @@ class QueryObject:
 
     annotation_layers: List[Dict[str, Any]]
     applied_time_extras: Dict[str, str]
+    apply_fetch_values_predicate: bool
     granularity: Optional[str]
     from_dttm: Optional[datetime]
     to_dttm: Optional[datetime]
+    inner_from_dttm: Optional[datetime]
+    inner_to_dttm: Optional[datetime]
     is_timeseries: bool
     time_shift: Optional[timedelta]
     groupby: List[str]
-    metrics: List[Union[Dict[str, Any], str]]
+    metrics: Optional[List[Metric]]
     row_limit: int
     row_offset: int
-    filter: List[Dict[str, Any]]
+    filter: List[QueryObjectFilterClause]
     timeseries_limit: int
     timeseries_limit_metric: Optional[Metric]
     order_desc: bool
     extras: Dict[str, Any]
     columns: List[str]
-    orderby: List[List[str]]
+    orderby: List[OrderBy]
     post_processing: List[Dict[str, Any]]
+    datasource: Optional[BaseDatasource]
+    result_type: Optional[ChartDataResultType]
+    is_rowcount: bool
+    time_offsets: List[str]
 
     def __init__(
         self,
+        datasource: Optional[DatasourceDict] = None,
+        result_type: Optional[ChartDataResultType] = None,
         annotation_layers: Optional[List[Dict[str, Any]]] = None,
         applied_time_extras: Optional[Dict[str, str]] = None,
+        apply_fetch_values_predicate: bool = False,
         granularity: Optional[str] = None,
-        metrics: Optional[List[Union[Dict[str, Any], str]]] = None,
+        metrics: Optional[List[Metric]] = None,
         groupby: Optional[List[str]] = None,
-        filters: Optional[List[Dict[str, Any]]] = None,
+        filters: Optional[List[QueryObjectFilterClause]] = None,
         time_range: Optional[str] = None,
         time_shift: Optional[str] = None,
         is_timeseries: Optional[bool] = None,
@@ -100,14 +120,27 @@ class QueryObject:
         order_desc: bool = True,
         extras: Optional[Dict[str, Any]] = None,
         columns: Optional[List[str]] = None,
-        orderby: Optional[List[List[str]]] = None,
+        orderby: Optional[List[OrderBy]] = None,
         post_processing: Optional[List[Optional[Dict[str, Any]]]] = None,
+        is_rowcount: bool = False,
         **kwargs: Any,
     ):
-        annotation_layers = annotation_layers or []
-        metrics = metrics or []
+        columns = columns or []
+        groupby = groupby or []
         extras = extras or {}
-        is_sip_38 = is_feature_enabled("SIP_38_VIZ_REARCHITECTURE")
+        annotation_layers = annotation_layers or []
+        self.time_offsets = kwargs.get("time_offsets", [])
+        self.inner_from_dttm = kwargs.get("inner_from_dttm")
+        self.inner_to_dttm = kwargs.get("inner_to_dttm")
+
+        self.is_rowcount = is_rowcount
+        self.datasource = None
+        if datasource:
+            self.datasource = ConnectorRegistry.get_datasource(
+                str(datasource["type"]), int(datasource["id"]), db.session
+            )
+        self.result_type = result_type
+        self.apply_fetch_values_predicate = apply_fetch_values_predicate or False
         self.annotation_layers = [
             layer
             for layer in annotation_layers
@@ -126,32 +159,29 @@ class QueryObject:
             time_range=time_range,
             time_shift=time_shift,
         )
-        # is_timeseries is True if time column is in groupby
+        # is_timeseries is True if time column is in either columns or groupby
+        # (both are dimensions)
         self.is_timeseries = (
             is_timeseries
             if is_timeseries is not None
-            else (DTTM_ALIAS in groupby if groupby else False)
+            else DTTM_ALIAS in columns + groupby
         )
         self.time_range = time_range
         self.time_shift = parse_human_timedelta(time_shift)
         self.post_processing = [
             post_proc for post_proc in post_processing or [] if post_proc
         ]
-        if not is_sip_38:
-            self.groupby = groupby or []
 
         # Support metric reference/definition in the format of
         #   1. 'metric_name'   - name of predefined metric
         #   2. { label: 'label_name' }  - legacy format for a predefined metric
         #   3. { expressionType: 'SIMPLE' | 'SQL', ... } - adhoc metric
-        self.metrics = [
-            metric
-            if isinstance(metric, str) or "expressionType" in metric
-            else metric["label"]  # type: ignore
-            for metric in metrics
+        self.metrics = metrics and [
+            x if isinstance(x, str) or is_adhoc_metric(x) else x["label"]
+            for x in metrics
         ]
 
-        self.row_limit = row_limit or config["ROW_LIMIT"]
+        self.row_limit = config["ROW_LIMIT"] if row_limit is None else row_limit
         self.row_offset = row_offset or 0
         self.filter = filters or []
         self.timeseries_limit = timeseries_limit
@@ -159,17 +189,13 @@ class QueryObject:
         self.order_desc = order_desc
         self.extras = extras
 
-        if config["SIP_15_ENABLED"] and "time_range_endpoints" not in self.extras:
-            self.extras["time_range_endpoints"] = get_time_range_endpoints(form_data={})
-
-        self.columns = columns or []
-        if is_sip_38 and groupby:
-            self.columns += groupby
-            logger.warning(
-                "The field `groupby` is deprecated. Viz plugins should "
-                "pass all selectables via the `columns` field"
+        if config["SIP_15_ENABLED"]:
+            self.extras["time_range_endpoints"] = get_time_range_endpoints(
+                form_data=self.extras
             )
 
+        self.columns = columns
+        self.groupby = groupby or []
         self.orderby = orderby or []
 
         # rename deprecated fields
@@ -214,13 +240,44 @@ class QueryObject:
 
     @property
     def metric_names(self) -> List[str]:
-        return get_metric_names(self.metrics)
+        """Return metrics names (labels), coerce adhoc metrics to strings."""
+        return get_metric_names(self.metrics or [])
+
+    @property
+    def column_names(self) -> List[str]:
+        """Return column names (labels). Reserved for future adhoc calculated
+        columns."""
+        return self.columns
+
+    def validate(
+        self, raise_exceptions: Optional[bool] = True
+    ) -> Optional[QueryObjectValidationError]:
+        """Validate query object"""
+        error: Optional[QueryObjectValidationError] = None
+        all_labels = self.metric_names + self.column_names
+        if len(set(all_labels)) < len(all_labels):
+            dup_labels = find_duplicates(all_labels)
+            error = QueryObjectValidationError(
+                _(
+                    "Duplicate column/metric labels: %(labels)s. Please make "
+                    "sure all columns and metrics have a unique label.",
+                    labels=", ".join(f'"{x}"' for x in dup_labels),
+                )
+            )
+        if error and raise_exceptions:
+            raise error
+        return error
 
     def to_dict(self) -> Dict[str, Any]:
         query_object_dict = {
+            "apply_fetch_values_predicate": self.apply_fetch_values_predicate,
             "granularity": self.granularity,
+            "groupby": self.groupby,
             "from_dttm": self.from_dttm,
             "to_dttm": self.to_dttm,
+            "inner_from_dttm": self.inner_from_dttm,
+            "inner_to_dttm": self.inner_to_dttm,
+            "is_rowcount": self.is_rowcount,
             "is_timeseries": self.is_timeseries,
             "metrics": self.metrics,
             "row_limit": self.row_limit,
@@ -233,9 +290,6 @@ class QueryObject:
             "columns": self.columns,
             "orderby": self.orderby,
         }
-        if not is_feature_enabled("SIP_38_VIZ_REARCHITECTURE"):
-            query_object_dict["groupby"] = self.groupby
-
         return query_object_dict
 
     def cache_key(self, **extra: Any) -> str:
@@ -249,12 +303,24 @@ class QueryObject:
         cache_dict = self.to_dict()
         cache_dict.update(extra)
 
-        for k in ["from_dttm", "to_dttm"]:
-            del cache_dict[k]
+        # TODO: the below KVs can all be cleaned up and moved to `to_dict()` at some
+        #  predetermined point in time when orgs are aware that the previously
+        #  chached results will be invalidated.
+        if not self.apply_fetch_values_predicate:
+            del cache_dict["apply_fetch_values_predicate"]
+        if self.datasource:
+            cache_dict["datasource"] = self.datasource.uid
+        if self.result_type:
+            cache_dict["result_type"] = self.result_type
         if self.time_range:
             cache_dict["time_range"] = self.time_range
         if self.post_processing:
             cache_dict["post_processing"] = self.post_processing
+        if self.time_offsets:
+            cache_dict["time_offsets"] = self.time_offsets
+
+        for k in ["from_dttm", "to_dttm"]:
+            del cache_dict[k]
 
         annotation_fields = [
             "annotationType",
@@ -275,14 +341,7 @@ class QueryObject:
         if annotation_layers:
             cache_dict["annotation_layers"] = annotation_layers
 
-        json_data = self.json_dumps(cache_dict, sort_keys=True)
-        return hashlib.md5(json_data.encode("utf-8")).hexdigest()
-
-    @staticmethod
-    def json_dumps(obj: Any, sort_keys: bool = False) -> str:
-        return json.dumps(
-            obj, default=json_int_dttm_ser, ignore_nan=True, sort_keys=sort_keys
-        )
+        return md5_sha_from_dict(cache_dict, default=json_int_dttm_ser, ignore_nan=True)
 
     def exec_post_processing(self, df: DataFrame) -> DataFrame:
         """
