@@ -43,21 +43,31 @@ from sqlalchemy import (
     Table,
     Text,
     UniqueConstraint,
+    update,
 )
+from sqlalchemy.engine.base import Connection
 from sqlalchemy.ext.hybrid import hybrid_property
 from sqlalchemy.orm import backref, relationship, Session
+from sqlalchemy.orm.mapper import Mapper
 from sqlalchemy.sql import expression
-from sqlalchemy_utils import EncryptedType
 
-from superset import conf, db, is_feature_enabled, security_manager
+from superset import conf, db, security_manager
 from superset.connectors.base.models import BaseColumn, BaseDatasource, BaseMetric
 from superset.constants import NULL_STRING
 from superset.exceptions import SupersetException
+from superset.extensions import encrypted_field_factory
 from superset.models.core import Database
 from superset.models.helpers import AuditMixinNullable, ImportExportMixin, QueryResult
-from superset.typing import FilterValues, Granularity, Metric, QueryObjectDict
+from superset.typing import (
+    AdhocMetric,
+    FilterValues,
+    Granularity,
+    Metric,
+    QueryObjectDict,
+)
 from superset.utils import core as utils
 from superset.utils.date_parser import parse_human_datetime, parse_human_timedelta
+from superset.utils.memoized import memoized
 
 try:
     import requests
@@ -87,7 +97,6 @@ try:
 except ImportError:
     pass
 
-IS_SIP_38 = is_feature_enabled("SIP_38_VIZ_REARCHITECTURE")
 DRUID_TZ = conf.get("DRUID_TZ")
 POST_AGG_TYPE = "postagg"
 metadata = Model.metadata  # pylint: disable=no-member
@@ -139,7 +148,7 @@ class DruidCluster(Model, AuditMixinNullable, ImportExportMixin):
     metadata_last_refreshed = Column(DateTime)
     cache_timeout = Column(Integer)
     broker_user = Column(String(255))
-    broker_pass = Column(EncryptedType(String(255), conf.get("SECRET_KEY")))
+    broker_pass = Column(encrypted_field_factory.create(String(255)))
 
     export_fields = [
         "cluster_name",
@@ -193,7 +202,7 @@ class DruidCluster(Model, AuditMixinNullable, ImportExportMixin):
         return json.loads(requests.get(endpoint, auth=auth).text)["version"]
 
     @property  # type: ignore
-    @utils.memoized
+    @memoized
     def druid_version(self) -> str:
         return self.get_druid_version()
 
@@ -1011,7 +1020,7 @@ class DruidDatasource(Model, BaseDatasource):
         return ret
 
     @staticmethod
-    def druid_type_from_adhoc_metric(adhoc_metric: Dict[str, Any]) -> str:
+    def druid_type_from_adhoc_metric(adhoc_metric: AdhocMetric) -> str:
         column_type = adhoc_metric["column"]["type"].lower()
         aggregate = adhoc_metric["aggregate"].lower()
 
@@ -1026,7 +1035,7 @@ class DruidDatasource(Model, BaseDatasource):
     def get_aggregations(
         metrics_dict: Dict[str, Any],
         saved_metrics: Set[str],
-        adhoc_metrics: Optional[List[Dict[str, Any]]] = None,
+        adhoc_metrics: Optional[List[AdhocMetric]] = None,
     ) -> "OrderedDict[str, Any]":
         """
         Returns a dictionary of aggregation metric names to aggregation json objects
@@ -1139,8 +1148,19 @@ class DruidDatasource(Model, BaseDatasource):
         phase: int = 2,
         client: Optional["PyDruid"] = None,
         order_desc: bool = True,
+        is_rowcount: bool = False,
+        apply_fetch_values_predicate: bool = False,
     ) -> str:
         """Runs a query against Druid and returns a dataframe."""
+        # is_rowcount and apply_fetch_values_predicate is only
+        # supported on SQL connector
+        if is_rowcount:
+            raise SupersetException("is_rowcount is not supported on Druid connector")
+        if apply_fetch_values_predicate:
+            raise SupersetException(
+                "apply_fetch_values_predicate is not supported on Druid connector"
+            )
+
         # TODO refactor into using a TBD Query object
         client = client or self.cluster.get_pydruid_client()
         row_limit = row_limit or conf.get("ROW_LIMIT")
@@ -1174,8 +1194,7 @@ class DruidDatasource(Model, BaseDatasource):
         )
 
         # the dimensions list with dimensionSpecs expanded
-        columns_ = columns if IS_SIP_38 else groupby
-        dimensions = self.get_dimensions(columns_, columns_dict) if columns_ else []
+        dimensions = self.get_dimensions(groupby, columns_dict) if groupby else []
 
         extras = extras or {}
         qry = dict(
@@ -1209,9 +1228,7 @@ class DruidDatasource(Model, BaseDatasource):
 
         order_direction = "descending" if order_desc else "ascending"
 
-        if (IS_SIP_38 and not metrics and columns and "__time" not in columns) or (
-            not IS_SIP_38 and columns
-        ):
+        if columns:
             columns.append("__time")
             del qry["post_aggregations"]
             del qry["aggregations"]
@@ -1221,20 +1238,11 @@ class DruidDatasource(Model, BaseDatasource):
             qry["granularity"] = "all"
             qry["limit"] = row_limit
             client.scan(**qry)
-        elif (IS_SIP_38 and columns) or (
-            not IS_SIP_38 and not groupby and not having_filters
-        ):
+        elif not groupby and not having_filters:
             logger.info("Running timeseries query for no groupby values")
             del qry["dimensions"]
             client.timeseries(**qry)
-        elif (
-            not having_filters
-            and order_desc
-            and (
-                (IS_SIP_38 and columns and len(columns) == 1)
-                or (not IS_SIP_38 and groupby and len(groupby) == 1)
-            )
-        ):
+        elif not having_filters and order_desc and (groupby and len(groupby) == 1):
             dim = list(qry["dimensions"])[0]
             logger.info("Running two-phase topn query for dimension [{}]".format(dim))
             pre_qry = deepcopy(qry)
@@ -1286,7 +1294,7 @@ class DruidDatasource(Model, BaseDatasource):
             qry["metric"] = list(qry["aggregations"].keys())[0]
             client.topn(**qry)
             logger.info("Phase 2 Complete")
-        elif having_filters or ((IS_SIP_38 and columns) or (not IS_SIP_38 and groupby)):
+        elif having_filters or groupby:
             # If grouping on multiple fields or using a having filter
             # we have to force a groupby query
             logger.info("Running groupby query for dimensions [{}]".format(dimensions))
@@ -1397,9 +1405,7 @@ class DruidDatasource(Model, BaseDatasource):
                 df=df, query=query_str, duration=datetime.now() - qry_start_dttm
             )
 
-        df = self.homogenize_types(
-            df, query_obj.get("columns" if IS_SIP_38 else "groupby", [])
-        )
+        df = self.homogenize_types(df, query_obj.get("groupby", []))
         df.columns = [
             DTTM_ALIAS if c in ("timestamp", "__time") else c for c in df.columns
         ]
@@ -1415,8 +1421,7 @@ class DruidDatasource(Model, BaseDatasource):
         if DTTM_ALIAS in df.columns:
             cols += [DTTM_ALIAS]
 
-        if not IS_SIP_38:
-            cols += query_obj.get("groupby") or []
+        cols += query_obj.get("groupby") or []
         cols += query_obj.get("columns") or []
         cols += query_obj.get("metrics") or []
 
@@ -1520,7 +1525,9 @@ class DruidDatasource(Model, BaseDatasource):
             eq = cls.filter_values_handler(
                 eq,
                 is_list_target=is_list_target,
-                target_column_is_numeric=is_numeric_col,
+                target_column_type=utils.GenericDataType.NUMERIC
+                if is_numeric_col
+                else utils.GenericDataType.STRING,
             )
 
             # For these two ops, could have used Dimension,
@@ -1683,6 +1690,25 @@ class DruidDatasource(Model, BaseDatasource):
         latest_metadata = self.latest_metadata() or {}
         return [{"name": k, "type": v.get("type")} for k, v in latest_metadata.items()]
 
+    @staticmethod
+    def update_datasource(
+        _mapper: Mapper, _connection: Connection, obj: Union[DruidColumn, DruidMetric]
+    ) -> None:
+        """
+        Forces an update to the datasource's changed_on value when a metric or column on
+        the datasource is updated. This busts the cache key for all charts that use the
+        datasource.
+
+        :param _mapper: Unused.
+        :param _connection: Unused.
+        :param obj: The metric or column that was updated.
+        """
+        db.session.execute(
+            update(DruidDatasource).where(DruidDatasource.id == obj.datasource.id)
+        )
+
 
 sa.event.listen(DruidDatasource, "after_insert", security_manager.set_perm)
 sa.event.listen(DruidDatasource, "after_update", security_manager.set_perm)
+sa.event.listen(DruidMetric, "after_update", DruidDatasource.update_datasource)
+sa.event.listen(DruidColumn, "after_update", DruidDatasource.update_datasource)
