@@ -18,6 +18,7 @@ from contextlib import closing
 from typing import Dict, List, Optional, TYPE_CHECKING
 
 from flask_babel import lazy_gettext as _
+from sqlalchemy.exc import NoSuchTableError
 from sqlalchemy.sql.type_api import TypeEngine
 
 from superset.errors import ErrorLevel, SupersetError, SupersetErrorType
@@ -41,6 +42,10 @@ def get_physical_table_metadata(
     db_dialect = database.get_dialect()
     # ensure empty schema
     _schema_name = schema_name if schema_name else None
+    # Table does not exist or is not visible to a connection.
+    if not database.has_table_by_name(table_name, schema=_schema_name):
+        raise NoSuchTableError
+
     cols = database.get_columns(table_name, schema=_schema_name)
     for col in cols:
         try:
