@@ -24,7 +24,8 @@ from typing import Any, Dict
 from urllib import request
 
 import pandas as pd
-from sqlalchemy import BigInteger, Date, DateTime, Float, String, Text
+from flask import current_app
+from sqlalchemy import BigInteger, Boolean, Date, DateTime, Float, String, Text
 from sqlalchemy.orm import Session
 from sqlalchemy.sql.visitors import VisitableType
 
@@ -37,10 +38,11 @@ logger = logging.getLogger(__name__)
 CHUNKSIZE = 512
 VARCHAR = re.compile(r"VARCHAR\((\d+)\)", re.IGNORECASE)
 
-JSON_KEYS = {"params", "template_params", "extra"}
+JSON_KEYS = {"params", "template_params"}
 
 
 type_map = {
+    "BOOLEAN": Boolean(),
     "VARCHAR": String(255),
     "STRING": String(255),
     "TEXT": Text(),
@@ -90,17 +92,18 @@ def import_dataset(
     # TODO (betodealmeida): move this logic to import_from_dict
     config = config.copy()
     for key in JSON_KEYS:
-        if config.get(key):
+        if config.get(key) is not None:
             try:
                 config[key] = json.dumps(config[key])
             except TypeError:
                 logger.info("Unable to encode `%s` field: %s", key, config[key])
     for metric in config.get("metrics", []):
-        if metric.get("extra"):
+        if metric.get("extra") is not None:
             try:
                 metric["extra"] = json.dumps(metric["extra"])
             except TypeError:
                 logger.info("Unable to encode `extra` field: %s", metric["extra"])
+                metric["extra"] = None
 
     # should we delete columns and metrics not present in the current import?
     sync = ["columns", "metrics"] if overwrite else []
@@ -114,7 +117,13 @@ def import_dataset(
         session.flush()
 
     example_database = get_example_database()
-    table_exists = example_database.has_table_by_name(dataset.table_name)
+    try:
+        table_exists = example_database.has_table_by_name(dataset.table_name)
+    except Exception as ex:
+        # MySQL doesn't play nice with GSheets table names
+        logger.warning("Couldn't check if table %s exists, stopping import")
+        raise ex
+
     if data_uri and (not table_exists or force_data):
         load_data(data_uri, dataset, example_database, session)
 
@@ -124,6 +133,7 @@ def import_dataset(
 def load_data(
     data_uri: str, dataset: SqlaTable, example_database: Database, session: Session
 ) -> None:
+
     data = request.urlopen(data_uri)
     if data_uri.endswith(".gz"):
         data = gzip.open(data)
@@ -136,7 +146,9 @@ def load_data(
             df[column_name] = pd.to_datetime(df[column_name])
 
     # reuse session when loading data if possible, to make import atomic
-    if example_database.sqlalchemy_uri == get_example_database().sqlalchemy_uri:
+    if example_database.sqlalchemy_uri == current_app.config.get(
+        "SQLALCHEMY_DATABASE_URI"
+    ) or not current_app.config.get("SQLALCHEMY_EXAMPLES_URI"):
         logger.info("Loading data inside the import transaction")
         connection = session.connection()
     else:
