@@ -17,26 +17,26 @@
 """Loads datasets, dashboards and slices in a new superset instance"""
 import json
 import os
-import textwrap
+from typing import List
 
 import pandas as pd
 from sqlalchemy import DateTime, String
 from sqlalchemy.sql import column
 
-from superset import db
+from superset import app, db
 from superset.connectors.sqla.models import SqlMetric
 from superset.models.dashboard import Dashboard
 from superset.models.slice import Slice
 from superset.utils import core as utils
 
+from ..connectors.base.models import BaseDatasource
 from .helpers import (
-    config,
-    EXAMPLES_FOLDER,
     get_example_data,
+    get_examples_folder,
     get_slice_json,
+    get_table_connector_registry,
     merge_slice,
     misc_dash_slices,
-    TBL,
     update_slice_ids,
 )
 
@@ -45,7 +45,7 @@ def load_world_bank_health_n_pop(  # pylint: disable=too-many-locals, too-many-s
     only_metadata: bool = False, force: bool = False, sample: bool = False,
 ) -> None:
     """Loads the world bank health dataset, slices and a dashboard"""
-    tbl_name = "wb_health_population"
+    tbl_name = "World Bank Health Data"
     database = utils.get_example_database()
     table_exists = database.has_table_by_name(tbl_name)
 
@@ -76,11 +76,14 @@ def load_world_bank_health_n_pop(  # pylint: disable=too-many-locals, too-many-s
             index=False,
         )
 
-    print("Creating table [wb_health_population] reference")
-    tbl = db.session.query(TBL).filter_by(table_name=tbl_name).first()
+    print("Creating table [World Bank Health Data] reference")
+    table = get_table_connector_registry()
+    tbl = db.session.query(table).filter_by(table_name=tbl_name).first()
     if not tbl:
-        tbl = TBL(table_name=tbl_name)
-    tbl.description = utils.readfile(os.path.join(EXAMPLES_FOLDER, "countries.md"))
+        tbl = table(table_name=tbl_name)
+    tbl.description = utils.readfile(
+        os.path.join(get_examples_folder(), "countries.md")
+    )
     tbl.main_dttm_col = "year"
     tbl.database = database
     tbl.filter_select_enabled = True
@@ -105,6 +108,32 @@ def load_world_bank_health_n_pop(  # pylint: disable=too-many-locals, too-many-s
     db.session.commit()
     tbl.fetch_metadata()
 
+    slices = create_slices(tbl)
+    misc_dash_slices.add(slices[-1].slice_name)
+    for slc in slices:
+        merge_slice(slc)
+
+    print("Creating a World's Health Bank dashboard")
+    dash_name = "World Bank's Data"
+    slug = "world_health"
+    dash = db.session.query(Dashboard).filter_by(slug=slug).first()
+
+    if not dash:
+        dash = Dashboard()
+    dash.published = True
+    pos = dashboard_positions
+    update_slice_ids(pos, slices)
+
+    dash.dashboard_title = dash_name
+    dash.position_json = json.dumps(pos, indent=4)
+    dash.slug = slug
+
+    dash.slices = slices[:-1]
+    db.session.merge(dash)
+    db.session.commit()
+
+
+def create_slices(tbl: BaseDatasource) -> List[Slice]:
     metric = "sum__SP_POP_TOTL"
     metrics = ["sum__SP_POP_TOTL"]
     secondary_metric = {
@@ -118,14 +147,13 @@ def load_world_bank_health_n_pop(  # pylint: disable=too-many-locals, too-many-s
         "hasCustomLabel": True,
         "label": "Rural Population",
     }
-
     defaults = {
         "compare_lag": "10",
         "compare_suffix": "o10Y",
         "limit": "25",
         "granularity_sqla": "year",
         "groupby": [],
-        "row_limit": config["ROW_LIMIT"],
+        "row_limit": app.config["ROW_LIMIT"],
         "since": "2014-01-01",
         "until": "2014-01-02",
         "time_range": "2014-01-01 : 2014-01-02",
@@ -136,8 +164,7 @@ def load_world_bank_health_n_pop(  # pylint: disable=too-many-locals, too-many-s
         "show_bubbles": True,
     }
 
-    print("Creating slices")
-    slices = [
+    return [
         Slice(
             slice_name="Region Filter",
             viz_type="filter_box",
@@ -340,31 +367,14 @@ def load_world_bank_health_n_pop(  # pylint: disable=too-many-locals, too-many-s
             ),
         ),
     ]
-    misc_dash_slices.add(slices[-1].slice_name)
-    for slc in slices:
-        merge_slice(slc)
 
-    print("Creating a World's Health Bank dashboard")
-    dash_name = "World Bank's Data"
-    slug = "world_health"
-    dash = db.session.query(Dashboard).filter_by(slug=slug).first()
 
-    if not dash:
-        dash = Dashboard()
-    dash.published = True
-    js = textwrap.dedent(
-        """\
-{
+dashboard_positions = {
     "CHART-36bfc934": {
         "children": [],
         "id": "CHART-36bfc934",
-        "meta": {
-            "chartId": 40,
-            "height": 25,
-            "sliceName": "Region Filter",
-            "width": 2
-        },
-        "type": "CHART"
+        "meta": {"chartId": 40, "height": 25, "sliceName": "Region Filter", "width": 2},
+        "type": "CHART",
     },
     "CHART-37982887": {
         "children": [],
@@ -373,9 +383,9 @@ def load_world_bank_health_n_pop(  # pylint: disable=too-many-locals, too-many-s
             "chartId": 41,
             "height": 25,
             "sliceName": "World's Population",
-            "width": 2
+            "width": 2,
         },
-        "type": "CHART"
+        "type": "CHART",
     },
     "CHART-17e0f8d8": {
         "children": [],
@@ -384,31 +394,21 @@ def load_world_bank_health_n_pop(  # pylint: disable=too-many-locals, too-many-s
             "chartId": 42,
             "height": 92,
             "sliceName": "Most Populated Countries",
-            "width": 3
+            "width": 3,
         },
-        "type": "CHART"
+        "type": "CHART",
     },
     "CHART-2ee52f30": {
         "children": [],
         "id": "CHART-2ee52f30",
-        "meta": {
-            "chartId": 43,
-            "height": 38,
-            "sliceName": "Growth Rate",
-            "width": 6
-        },
-        "type": "CHART"
+        "meta": {"chartId": 43, "height": 38, "sliceName": "Growth Rate", "width": 6},
+        "type": "CHART",
     },
     "CHART-2d5b6871": {
         "children": [],
         "id": "CHART-2d5b6871",
-        "meta": {
-            "chartId": 44,
-            "height": 52,
-            "sliceName": "% Rural",
-            "width": 7
-        },
-        "type": "CHART"
+        "meta": {"chartId": 44, "height": 52, "sliceName": "% Rural", "width": 7},
+        "type": "CHART",
     },
     "CHART-0fd0d252": {
         "children": [],
@@ -417,9 +417,9 @@ def load_world_bank_health_n_pop(  # pylint: disable=too-many-locals, too-many-s
             "chartId": 45,
             "height": 50,
             "sliceName": "Life Expectancy VS Rural %",
-            "width": 8
+            "width": 8,
         },
-        "type": "CHART"
+        "type": "CHART",
     },
     "CHART-97f4cb48": {
         "children": [],
@@ -428,9 +428,9 @@ def load_world_bank_health_n_pop(  # pylint: disable=too-many-locals, too-many-s
             "chartId": 46,
             "height": 38,
             "sliceName": "Rural Breakdown",
-            "width": 3
+            "width": 3,
         },
-        "type": "CHART"
+        "type": "CHART",
     },
     "CHART-b5e05d6f": {
         "children": [],
@@ -439,145 +439,80 @@ def load_world_bank_health_n_pop(  # pylint: disable=too-many-locals, too-many-s
             "chartId": 47,
             "height": 50,
             "sliceName": "World's Pop Growth",
-            "width": 4
+            "width": 4,
         },
-        "type": "CHART"
+        "type": "CHART",
     },
     "CHART-e76e9f5f": {
         "children": [],
         "id": "CHART-e76e9f5f",
-        "meta": {
-            "chartId": 48,
-            "height": 50,
-            "sliceName": "Box plot",
-            "width": 4
-        },
-        "type": "CHART"
+        "meta": {"chartId": 48, "height": 50, "sliceName": "Box plot", "width": 4},
+        "type": "CHART",
     },
     "CHART-a4808bba": {
         "children": [],
         "id": "CHART-a4808bba",
-        "meta": {
-            "chartId": 49,
-            "height": 50,
-            "sliceName": "Treemap",
-            "width": 8
-        },
-        "type": "CHART"
+        "meta": {"chartId": 49, "height": 50, "sliceName": "Treemap", "width": 8},
+        "type": "CHART",
+    },
+    "CHART-3nc0d8sk": {
+        "children": [],
+        "id": "CHART-3nc0d8sk",
+        "meta": {"chartId": 50, "height": 50, "sliceName": "Treemap", "width": 8},
+        "type": "CHART",
     },
     "COLUMN-071bbbad": {
-        "children": [
-            "ROW-1e064e3c",
-            "ROW-afdefba9"
-        ],
+        "children": ["ROW-1e064e3c", "ROW-afdefba9"],
         "id": "COLUMN-071bbbad",
-        "meta": {
-            "background": "BACKGROUND_TRANSPARENT",
-            "width": 9
-        },
-        "type": "COLUMN"
+        "meta": {"background": "BACKGROUND_TRANSPARENT", "width": 9},
+        "type": "COLUMN",
     },
     "COLUMN-fe3914b8": {
-        "children": [
-            "CHART-36bfc934",
-            "CHART-37982887"
-        ],
+        "children": ["CHART-36bfc934", "CHART-37982887"],
         "id": "COLUMN-fe3914b8",
-        "meta": {
-            "background": "BACKGROUND_TRANSPARENT",
-            "width": 2
-        },
-        "type": "COLUMN"
+        "meta": {"background": "BACKGROUND_TRANSPARENT", "width": 2},
+        "type": "COLUMN",
     },
     "GRID_ID": {
-        "children": [
-            "ROW-46632bc2",
-            "ROW-3fa26c5d",
-            "ROW-812b3f13"
-        ],
+        "children": ["ROW-46632bc2", "ROW-3fa26c5d", "ROW-812b3f13"],
         "id": "GRID_ID",
-        "type": "GRID"
+        "type": "GRID",
     },
     "HEADER_ID": {
         "id": "HEADER_ID",
-        "meta": {
-            "text": "World's Bank Data"
-        },
-        "type": "HEADER"
-    },
-    "ROOT_ID": {
-        "children": [
-            "GRID_ID"
-        ],
-        "id": "ROOT_ID",
-        "type": "ROOT"
+        "meta": {"text": "World's Bank Data"},
+        "type": "HEADER",
     },
+    "ROOT_ID": {"children": ["GRID_ID"], "id": "ROOT_ID", "type": "ROOT"},
     "ROW-1e064e3c": {
-        "children": [
-            "COLUMN-fe3914b8",
-            "CHART-2d5b6871"
-        ],
+        "children": ["COLUMN-fe3914b8", "CHART-2d5b6871"],
         "id": "ROW-1e064e3c",
-        "meta": {
-            "background": "BACKGROUND_TRANSPARENT"
-        },
-        "type": "ROW"
+        "meta": {"background": "BACKGROUND_TRANSPARENT"},
+        "type": "ROW",
     },
     "ROW-3fa26c5d": {
-        "children": [
-            "CHART-b5e05d6f",
-            "CHART-0fd0d252"
-        ],
+        "children": ["CHART-b5e05d6f", "CHART-0fd0d252"],
         "id": "ROW-3fa26c5d",
-        "meta": {
-            "background": "BACKGROUND_TRANSPARENT"
-        },
-        "type": "ROW"
+        "meta": {"background": "BACKGROUND_TRANSPARENT"},
+        "type": "ROW",
     },
     "ROW-46632bc2": {
-        "children": [
-            "COLUMN-071bbbad",
-            "CHART-17e0f8d8"
-        ],
+        "children": ["COLUMN-071bbbad", "CHART-17e0f8d8"],
         "id": "ROW-46632bc2",
-        "meta": {
-            "background": "BACKGROUND_TRANSPARENT"
-        },
-        "type": "ROW"
+        "meta": {"background": "BACKGROUND_TRANSPARENT"},
+        "type": "ROW",
     },
     "ROW-812b3f13": {
-        "children": [
-            "CHART-a4808bba",
-            "CHART-e76e9f5f"
-        ],
+        "children": ["CHART-a4808bba", "CHART-e76e9f5f"],
         "id": "ROW-812b3f13",
-        "meta": {
-            "background": "BACKGROUND_TRANSPARENT"
-        },
-        "type": "ROW"
+        "meta": {"background": "BACKGROUND_TRANSPARENT"},
+        "type": "ROW",
     },
     "ROW-afdefba9": {
-        "children": [
-            "CHART-2ee52f30",
-            "CHART-97f4cb48"
-        ],
+        "children": ["CHART-2ee52f30", "CHART-97f4cb48"],
         "id": "ROW-afdefba9",
-        "meta": {
-            "background": "BACKGROUND_TRANSPARENT"
-        },
-        "type": "ROW"
+        "meta": {"background": "BACKGROUND_TRANSPARENT"},
+        "type": "ROW",
     },
-    "DASHBOARD_VERSION_KEY": "v2"
+    "DASHBOARD_VERSION_KEY": "v2",
 }
-    """
-    )
-    pos = json.loads(js)
-    update_slice_ids(pos, slices)
-
-    dash.dashboard_title = dash_name
-    dash.position_json = json.dumps(pos, indent=4)
-    dash.slug = slug
-
-    dash.slices = slices[:-1]
-    db.session.merge(dash)
-    db.session.commit()
