@@ -65,7 +65,7 @@ class R(BaseSupersetView):  # pylint: disable=invalid-name
     def shortner(self) -> FlaskResponse:  # pylint: disable=no-self-use
         url = request.form.get("data")
         if not self._validate_url(url):
-            logger.warning("Invalid URL: %s", url)
+            logger.warning("Invalid URL")
             return Response("Invalid URL", 400)
         obj = models.Url(url=url)
         db.session.add(obj)
